==> uvinit-0.1.1.tar.gz: uvinit-0.1.1/README.md <==
# uvinit

[![Documentation](https://img.shields.io/badge/documentation-go)](https://www.github.com/jlevy/simple-modern-uv)
[![image](https://img.shields.io/pypi/pyversions/uvinit.svg)](https://pypi.python.org/pypi/uvinit)
[![uv](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json)](https://github.com/astral-sh/uv)
[![Copier](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/copier-org/copier/master/img/badge/badge-grayscale-border.json)](https://github.com/copier-org/copier)
[![X (formerly Twitter)
Follow](https://img.shields.io/twitter/follow/ojoshe)](https://x.com/ojoshe)

## Usage

Two words:

**uvx uvinit**

It will guide you!

## What is uvinit?

A time-saving CLI tool to quickly start new Python projects with
[**uv**](https://github.com/astral-sh/uv) using the
[**simple-modern-uv**](https://github.com/jlevy/simple-modern-uv) template and
[**copier**]

It is tiny and sets up **uv**, **ruff** linting and formatting, **GitHub Actions**,
**publishing to PyPI**, **type checking**, and more.

## What Project Template Does it Use?

See [simple-modern-uv](https://github.com/jlevy/simple-modern-uv) for full docs!

If you have another copier-format template you want to use, however, you can specify it
with the `--template` argument.

## By Chance Is There a Short URL I Can Remember for This Handy Tool?

Funny you should ask!

Type [**git.new/uvinit**](https://git.new/uvinit) into your browser.

Tell your friends!

* * *

<div align="center">

<img width="600" alt="Step 1 of 3"
src="https://github.com/user-attachments/assets/216d3db0-de98-4131-be1d-dce38e926474" />

</div>

* * *

*This project was (of course) built using
[simple-modern-uv](https://github.com/jlevy/simple-modern-uv).*

==> uvinit-0.1.2.tar.gz: uvinit-0.1.2/README.md <==
# uvinit

[![Documentation](https://img.shields.io/badge/documentation-go)](https://www.github.com/jlevy/simple-modern-uv)
[![image](https://img.shields.io/pypi/pyversions/uvinit.svg)](https://pypi.python.org/pypi/uvinit)
[![uv](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json)](https://github.com/astral-sh/uv)
[![Copier](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/copier-org/copier/master/img/badge/badge-grayscale-border.json)](https://github.com/copier-org/copier)
[![X (formerly Twitter)
Follow](https://img.shields.io/twitter/follow/ojoshe)](https://x.com/ojoshe)

## Usage

Two words:

```
uvx uvinit
```

It will guide you!

## What is uvinit?

A time-saving CLI tool to quickly start new Python projects with
[**uv**](https://github.com/astral-sh/uv) using the
[**simple-modern-uv**](https://github.com/jlevy/simple-modern-uv) template and
[**copier**](https://github.com/copier-org/copier).

**`uvx uvinit`** will clone a new project template and help you set up your GitHub repo.
The template tiny and sets up **uv**, **ruff** linting and formatting, **GitHub
Actions**, **publishing to PyPI**, **type checking**, and more.

## What Project Template Does it Use?

See [simple-modern-uv](https://github.com/jlevy/simple-modern-uv) for full docs.
If you have another copier-format template you want to use, however, you can specify it
with the `--template` argument.

## By Chance Is There a Short URL I Can Remember for This Handy Tool?

Funny you should ask!

Type [**git.new/uvinit**](https://git.new/uvinit) into your browser.

Tell your friends!

* * *

<div align="center">

<img width="600" alt="Step 1 of 3"
src="https://github.com/user-attachments/assets/216d3db0-de98-4131-be1d-dce38e926474" />

</div>

* * *

*This project was (of course) built using
[simple-modern-uv](https://github.com/jlevy/simple-modern-uv).*
